<template>
  <div v-if="dialogVisible">
    <el-dialog :before-close="EscHandlerClose" :title="dialogTitleName" :visible.sync="dialogVisible" append-to-body>
      <template>
        <el-select v-model="SelectValue" placeholder="请选择" style="width: 135px">
          <el-option
            v-for="item in SelectOption"
            :key="item.key"
            :label="item.label"
            :value="item.value"
            style="width: 150px">
          </el-option>
        </el-select>
        <el-input v-model="SelectSearchValue" placeholder="输入值后进行模糊查询"
                  style="width: 260px;margin-left: 15px"></el-input>
        <el-button plain size="small" style="margin-left: 20px" type="primary" @click="SelectSearchHandler">查询
        </el-button>
      </template>
      <avue-crud :data="TableData" :option="this.codeType === 'btmCode' ? this.btmOption : this.option" @row-click="rowHandlerClick" :table-loading="loading">
        <template slot="radio" slot-scope="{row}">
          <el-radio v-model="radioValue" :label="row.$index" style="padding-left: 10px !important;">{{ '' }}
          </el-radio>
        </template>
      </avue-crud>
      <div style="height: 30px">
        <div
          style="display: inline-block;float: left;border: 1px solid #eeeeee;padding: 5px;margin-top: 5px;font-size: 14px ">
          已设置的值为:[{{ this.TreeAddform[codeName] == '' ? '未设置值' : this.TreeAddform[codeName] }}]
        </div>
        <div style="padding-top: 10px;display: flex; justify-content: flex-end;float: right;overflow: hidden">
          <el-button size="small" type="primary" @click="HandlerClickSave">确定</el-button>
          <el-button size="small" @click="HandlerClickEsc">取消</el-button>
        </div>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {defaultReferDataGrid, referDataGrid} from '@/api/MasterData/master'

export default {
  name: "ThemeChildren",
  props: {
    visible: {
      type: Boolean,
      default: false,
    },
    SelectOption: {
      type: Array,
    },
    dialogTitle: {
      type: String
    },
    TreeAddform: {
      type: Object
    },
    codeName: {
      type: String
    },
    codeType: {
      type: String
    },
    codeLcstatus: {
      type: String
    }
  },
  data() {
    return {
      SelectValue: 'id',
      SelectSearchValue: '',
      radioValue: '',
      LineParm: {},
      crudName: '',
      crudOid: '',
      TableData: [],
      loading:false,
      option: {
        addBtn: false,
        index: true,
        columnBtn: false,
        refreshBtn: false,
        border: true,
        menu: false,
        height: 380,
        rowKey: "oid",
        column: [
          {
            label: '',
            prop: 'radio',
            width: 60,
            display: false
          },
          {
            label: '英文名称',
            prop: 'id'
          },
          {
            label: '中文名称',
            prop: 'name'
          },
          {
            label: '描述',
            prop: 'description'
          }
        ]
      },
      btmOption:{
        addBtn: false,
        index: true,
        columnBtn: false,
        refreshBtn: false,
        border: true,
        menu: false,
        height:380,
        rowKey: "oid",
        column:[
          {
            label: '',
            prop: 'radio',
            width: 60,
            display: false
          },
          {
            label:'业务类型编号',
            prop:'id'
          },
          {
            label:'业务类型名称',
            prop:'name'
          },
          {
            label:'描述',
            prop:'description'
          }
        ]
      },
    }
  },
  created() {
    this.loading = true;
  },
  mounted() {
  },
  computed: {
    dialogVisible: {
      get() {
        return this.visible;
      },
      set(val) {
        this.$emit("update:visible", val);
      },
    },
    dialogTitleName() {
      return `为【${this.dialogTitle}】选取值`;
    },
  },
  methods: {
    //关闭表单
    EscHandlerClose() {
      this.dialogVisible = false;
      this.SelectSearchValue = '';
      this.SelectValue = 'id';
      this.radioValue = null;
      this.LineParm = {};
    },
    // 模糊查询
    SelectSearchHandler() {
      this.loading = true;
      if (!this.SelectOption || this.SelectOption.length === 0) {
        this.loading = false;
        return;
      }
      const Parameter = {};
      Parameter[`conditionMap['${this.SelectValue}']`] = this.SelectSearchValue;
      if(this.codeType === "btmCode"){
        this.btmDefaultRend(Parameter)
      }else {
        this.defaultSearchRend(Parameter);
      }
    },
    //表格行单选
    rowHandlerClick(row) {
      this.radioValue = row.$index;
      this.LineParm = row;
      this.crudName = row.name;
      this.crudOid = row.oid;
    },
    //确定
    HandlerClickSave() {
      if (Object.values(this.LineParm).length === 0) {
        this.$message.warning('请至少选择一条数据！')
      } else {
        this.EscHandlerClose();
        this.$emit('defineHandler', { crudName: this.crudName, crudOid: this.crudOid ,codeType:this.codeType});
      }
    },
    //取消
    HandlerClickEsc() {
      this.EscHandlerClose()
    },
    //接口
    defaultSearchRend(Parameter) {
      defaultReferDataGrid({
        referType: this.codeType,
        isMuti: 'false',
        'conditionMap["lcstatus"]': this.codeLcstatus,
        'limit': '-1',
        ...Parameter
      }).then(res => {
        this.TableData = res.data.records;
        this.loading = false;
      })
    },
    btmDefaultRend(Parameter) {
      referDataGrid({valueField: 'id', isMuti: 'false', 'limit': '-1', ...Parameter}).then(res => {
        this.TableData = res.data.data.records;
        this.loading = false;
      })
    },
  }
}
</script>

<style scoped>

</style>
